/*
 * Copyright (C) 2014-2016 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

#include "gazebo/common/Console.hh"
#include "gazebo/common/Exception.hh"
#include "gazebo/physics/dart/DARTCollision.hh"
#include "gazebo/physics/dart/DARTHeightmapShape.hh"

#include "gazebo/physics/dart/DARTHeightmapShapePrivate.hh"

using namespace gazebo;
using namespace physics;

//////////////////////////////////////////////////
DARTHeightmapShape::DARTHeightmapShape(CollisionPtr _parent)
  : HeightmapShape(_parent),
    dataPtr(new DARTHeightmapShapePrivate())
{
}

//////////////////////////////////////////////////
DARTHeightmapShape::~DARTHeightmapShape()
{
  delete dataPtr;
}

//////////////////////////////////////////////////
void DARTHeightmapShape::Init()
{
  gzwarn << "Not implemented!\n";
}
